searchData={"items":[{"type":"module","title":"Archive","doc":"`Archive` provides Elixir bindings to [`libarchive`](https://github.com/libarchive/libarchive) through the power of the wonderful [`Zigler`](https://hexdocs.pm/zigler/Zig.html) library.\n\n`Archive` provides a high-level API for interacting with archive files.","ref":"Archive.html"},{"type":"module","title":"Intro to `Archive`'s APIs - Archive","doc":"<!-- tabs-open -->","ref":"Archive.html#module-intro-to-archive-s-apis"},{"type":"module","title":"High-Level API - Archive","doc":"The `Archive` API is the highest-level API offered by `Archive`, and mostly consists of convenience functions for common\nuse cases with archives. It involves using the `Archive` struct as a container for archive information extracted from\narchives using the `Archive.Stream` API.\n\nIt also implements the `Inspect` protocol specially for providing information about the archive in a succinct manner.","ref":"Archive.html#module-high-level-api"},{"type":"module","title":"Streaming API - Archive","doc":"`Archive` implements archive traversal, reading, and writing as\nstreams. It does this in the `Archive.Stream` module.\n\n`Archive.Stream` implements both the `Enumerable` and `Collectable` protocol, modeled after `File.Stream` from the\nstandard library. This allows you to read from an archive, perform transformations, and redirect to a new archive,\nall lazily.\n\nAll implementations in the high-level API are built off of the streaming API.","ref":"Archive.html#module-streaming-api"},{"type":"module","title":"Low-Level API - Archive","doc":"> ####  Caution {: .error}\n>\n> The low-level API is a nearly one-to-one mapping to the `libarchive` C API. All of the low-level API\n> lives in the `Archive.Nif` module, and it is highly recommended to not use this API directly.\n>\n> If you choose to use this API, you will need to carefully consider resource management and proper error checking.\n\n<!-- tabs-close -->\n\nRealistically, you will likely mix the High-Level API and the Streaming API, since the Streaming API is required to\ntraverse the archive.","ref":"Archive.html#module-low-level-api"},{"type":"module","title":"Concepts - Archive","doc":"Like `libarchive`, `Archive` treats all files as streams first and foremost, but provides many convenient high-level APIs to make it more natural to work with archive.\n\nThere are four major operations that `Archive` performs:\n* [Reading Archives](#module-reading-archives)\n* [Writing Archives](#module-writing-archives)\n* [Writing to Disk](#module-writing-to-disk)\n* [Extracting to Disk](#module-extracting-to-disk)","ref":"Archive.html#module-concepts"},{"type":"module","title":"Reading Archives - Archive","doc":"As streams, archives are not conducive to random-access reads or seeks. Once archives are opened and read, they must be closed and reopened to read again. It is often a two-stage process to read an archive, where you read a list of the contents first, then selectively filter which items you want suring a second pass.\n\n`Archive` takes care of all resource allocations, initializations, and cleanup for you. Using the high-level API, you only need to provide a mapping function to determine what to do with each entry as it is streamed.\n\nThe mapping function will accept an `Archive.Entry` struct, which will contain metadata (such as path and size) information about the entry. You can use that information to determine what to do in your function.\n\nYou can also use function from the `Archive.Entry` module to perform different operations with the entry (most commonly `Archive.Entry.load/2`).","ref":"Archive.html#module-reading-archives"},{"type":"module","title":"Writing Archives - Archive","doc":"TODO","ref":"Archive.html#module-writing-archives"},{"type":"module","title":"Writing to Disk - Archive","doc":"TODO","ref":"Archive.html#module-writing-to-disk"},{"type":"module","title":"Extracting to Disk - Archive","doc":"TODO\n\n## `Inspect`\n\n`Archive`, `Archive.Stream`, and `Archive.Entry` provide custom implementations for the `Inspect` protocol.\n\nWhen inspecting `Archive`, the following custom options can be supplied to the `custom_options` option of inspect:\n\n* `:depth` - Depth of directories to display. Defaults to 3.\n* `:breadth` - Breadth of items to display. Defaults to 2.","ref":"Archive.html#module-extracting-to-disk"},{"type":"module","title":"Examples - Archive","doc":"```elixir\nIO.inspect(%Archive{} = a, custom_options: [depth: 3, breadth: 2])\n```\n\n```\n#Archive[zip]<\n147 entries (40 loaded), 506.0 KB\n───────────────\n  .editorconfig (166 B)\n  .github/ (1 items, 338 B)\n    workflows/ (1 items, 338 B)\n      deploy-theme.yml (338 B)\n  ... and 21 more\n>\n```","ref":"Archive.html#module-examples"},{"type":"function","title":"Archive.extract/2","doc":"Extracts the archive from the reader stream, extracting the archive\nto disk.\n\nAs opposed to the other `write` operations, which write a new archive,\n`extract` extracts the archive to disk at the target location.","ref":"Archive.html#extract/2"},{"type":"function","title":"Options - Archive.extract/2","doc":"* `:flags` - Controls optional behavior when extracting archive entries to disk.\n  Pass all flags you want to enable as a list. The available flags\n  and their default behavior is as follows:\n  * `:owner` - Do not try to set owner/group.\n  * `:perm` - Do obey umask, do not restore SUID/SGID/SVTX bits.\n  * `:time` - Do not restore mtime/atime.\n  * `:no_overwrite` - Replace existing files.\n  * `:unlink` - Try create first, unlink only if create fails with EEXIST.\n  * `:acl` - Do not restore ACLs.\n  * `:fflags` - Do not restore fflags.\n  * `:xattr` - Do not restore xattrs.\n  * `:secure_symlinks` - Do not try to guard against extracts redirected by symlinks. Note: With ARCHIVE_EXTRACT_UNLINK, will remove any intermediate symlink.\n  * `:secure_nodotdot` - Do not reject entries with '..' as path elements.\n  * `:no_autodir` - Create parent directories as needed.\n  * `:no_overwrite_newer` - Overwrite files, even if one on disk is newer.\n  * `:sparse` - Detect blocks of 0 and write holes instead.\n  * `:mac_metadata` - Do not restore Mac extended metadata. This has no effect except on Mac OS.\n  * `:no_hfs_compression` - Use HFS+ compression if it was compressed. This has no effect except on Mac OS v10.6 or later.\n  * `:hfs_compression_forced` - Do not use HFS+ compression if it was not compressed. This has no effect except on Mac OS v10.6 or later.\n  * `:secure_noabsolutepaths` - Do not reject entries with absolute paths\n  * `:clear_nochange_fflags` - Do not clear no-change flags when unlinking object\n  * `:safe_writes` - Do not extract atomically (using rename) The default value is `[]`.\n\n* `:to` (`t:String.t/0`) - Directory to extract to. Will create any intermediate directories as necessary. Defaults to the current working directory.\n\n* `:prefix` (`t:String.t/0`) - A prefix to apply to each archive entry.","ref":"Archive.html#extract/2-options"},{"type":"function","title":"Archive.index/2","doc":"","ref":"Archive.html#index/2"},{"type":"function","title":"Archive.new/0","doc":"Create a new `Archive` struct","ref":"Archive.html#new/0"},{"type":"function","title":"Archive.reader/2","doc":"Creates a new `Archive.Stream` that is capable of reading an archive.\n\nAttempts to infer whether the passed binary is a filename or in-memory\ndata to be read.","ref":"Archive.html#reader/2"},{"type":"function","title":"Options - Archive.reader/2","doc":"See [Reader Options](#stream/1-reader-options) for a list of the full options.","ref":"Archive.html#reader/2-options"},{"type":"function","title":"Archive.reader!/2","doc":"","ref":"Archive.html#reader!/2"},{"type":"function","title":"Archive.stream/1","doc":"Creates a new `Archive.Stream` that is capable of reading and writing an archive.","ref":"Archive.html#stream/1"},{"type":"function","title":"Options - Archive.stream/1","doc":"* `:writer` - The default value is `[format: :tar, filters: :none]`.\n\n* `:reader` - The default value is `[formats: [:cpio, :tar, :iso9660, :iso9660_rockridge, :zip, :empty, :ar, :ar_gnu, :ar_bsd, :mtree, :raw, :xar, :lha, :cab, :rar, :sevenz, :warc, :rar_v5], filters: [:none, :gzip, :bzip2, :compress, :lzma, :xz, :uu, :lzip, :lrzip, :lzop, :grzip, :lz4, :zstd, :rpm]]`.","ref":"Archive.html#stream/1-options"},{"type":"function","title":"Writer Options - Archive.stream/1","doc":"Configures the writer. If true, uses default options. If a keyword list,\nuses the following options:\n\n* `:format` - The format to use when writing the archive. Must be one of these supported\n  write formats: `[:cpio, :cpio_posix, :cpio_bin_le, :cpio_bin_be, :cpio_svr4_nocrc, :cpio_svr4_crc, :cpio_afio_large, :cpio_pwb, :shar, :shar_base, :shar_dump, :tar, :tar_ustar, :tar_pax_interchange, :tar_pax_restricted, :tar_gnutar, :iso9660, :zip, :mtree, :raw, :xar, :sevenz, :warc]`. The default value is `:tar`.\n\n* `:filters` - The filters to apply when writing. Can be `:all`, a single filter,\n  or a list of such filters. Available write filters are `[:none, :gzip, :bzip2, :compress, :lzma, :xz, :uu, :lzip, :lrzip, :lzop, :grzip, :lz4, :zstd]`. The default value is `:none`.\n\n* `:file` (`t:String.t/0`) - Required. The path or name of the file to write the archive to.","ref":"Archive.html#stream/1-writer-options"},{"type":"function","title":"Reader Options - Archive.stream/1","doc":"Configures the reader. If false, disables reading. If a keyword list,\nuses the following options:\n\n* `:formats` - Specifies the archive formats to support when reading. Can be a single format,\n  a list of such formats, or a keyword list with either `:only` or `:except` keys\n  containing lists of formats. Available reader formats are `[:cpio, :tar, :iso9660, :iso9660_rockridge, :zip, :empty, :ar, :ar_gnu, :ar_bsd, :mtree, :raw, :xar, :lha, :cab, :rar, :sevenz, :warc, :rar_v5]`. The default value is `:all`.\n\n* `:filters` - Specifies the filters to support when reading. Can be a single filter,\n  a list of such filters, or a keyword list with either `:only` or `:except` keys\n  containing lists of filters. Available reader filters are `[:none, :gzip, :bzip2, :compress, :lzma, :xz, :uu, :lzip, :lrzip, :lzop, :grzip, :lz4, :zstd, :rpm]` The default value is `[:none, :gzip, :bzip2, :compress, :lzma, :xz, :uu, :lzip, :lrzip, :lzop, :grzip, :lz4, :zstd, :rpm]`.\n\n* `:open` (`t:String.t/0`) - Required. The path or name of the archive to open.\n\n* `:as` - Specifies how to treat the opened archive. Available options are `[:file, :data, :auto]` The default value is `:auto`.","ref":"Archive.html#stream/1-reader-options"},{"type":"function","title":"Archive.stream!/1","doc":"","ref":"Archive.html#stream!/1"},{"type":"function","title":"Archive.update_entries/2","doc":"","ref":"Archive.html#update_entries/2"},{"type":"function","title":"Archive.update_info/2","doc":"","ref":"Archive.html#update_info/2"},{"type":"function","title":"Archive.writer/2","doc":"Creates a new `Archive.Stream` that is capable of writing an archive.\n\nOpens the writer at the given filepath.","ref":"Archive.html#writer/2"},{"type":"function","title":"Options - Archive.writer/2","doc":"See [Writer Options](#stream/1-writer-options) for a list of the full options.","ref":"Archive.html#writer/2-options"},{"type":"function","title":"Archive.writer!/2","doc":"","ref":"Archive.html#writer!/2"},{"type":"module","title":"Archive.Entry","doc":"`Archive.Entry` represents a single item in an archive.\n\nMost functions in this module will only work within the context of the aupplied mapping function given to `Archive.read/3`. This is because these functions require a reference to the archive while streaming and while the entry is the current item in the stream.","ref":"Archive.Entry.html"},{"type":"function","title":"Archive.Entry.extract/3","doc":"","ref":"Archive.Entry.html#extract/3"},{"type":"function","title":"Archive.Entry.new/1","doc":"Creates a new `Archive.Entry` struct. This is done implicitly during `Archive.read/3`.","ref":"Archive.Entry.html#new/1"},{"type":"function","title":"Archive.Entry.new!/1","doc":"","ref":"Archive.Entry.html#new!/1"},{"type":"function","title":"Archive.Entry.read_data/2","doc":"Loads the entry data into the archive. The archive is automatically passed to the current entry during `Archive.read/3`, `Archive.from_memory_streaming/3`, and `Archive.from_file_streaming/3`.","ref":"Archive.Entry.html#read_data/2"},{"type":"function","title":"Archive.Entry.read_data!/2","doc":"","ref":"Archive.Entry.html#read_data!/2"},{"type":"function","title":"Archive.Entry.read_header/2","doc":"","ref":"Archive.Entry.html#read_header/2"},{"type":"function","title":"Archive.Entry.write_header/2","doc":"","ref":"Archive.Entry.html#write_header/2"},{"type":"type","title":"Archive.Entry.t/0","doc":"","ref":"Archive.Entry.html#t:t/0"},{"type":"module","title":"Archive.Nif","doc":"> #### Proceed With Caution {: .error}\n>\n> The `Archive.Nif` module contains the functions that directly interact with `libarchive`.\n> It is generally discouraged to interact with this library directly. If you find you need\n> functionality not supported in the higher-level APIs, consider opening an issue first\n> if the feature would be generally applicable or desireable.\n\n`Archive.Nif` provides direct `Elixir` bindings to the `libarchive` C API. Most of the functions\nin this module are 1-to-1 mappings to the C API equivalent functions.\n\nThese functions work directly with references, rather than `Archive` or `Archive.Entry` structs.\n\nAs long as you use the `ArchiveReaderResource` and `ArchiveEntryResource` reference types, they will\nbe managed and garbage-collected by this module once created.\n\nMost functions in this module may raise `ErlangError` on failure. You should invoke **most** of\nthese functions using `Archive.Nif.safe_call/2` to catch the errors and return them as `:ok` or\nan `{:error, reason}` tuple\n\n## `libarchive` APIs\n\n`libarchive` distinguishes the following APIs:\n\n<!-- tabs-open -->\n### `archive_read`\n> #### Reading an Archive {: .info}\n>\n> Although `Archive`'s high-level API takes care of all of the resource management for you, it can still be useful to understand how it works:\n>   1) Create new archive reader object\n>   2) Update any global reader properties as appropriate. These properties determine supported compressions, formats, etc.\n>   3) Open the archive\n>   4) Repeatedly call archive_read_next_header to get information about\n>       successive archive entries.  Call archive_read_data to extract\n>      data for entries of interest.\n>   5) Cleanup archive reader object\n\n### `archive-write`\n> #### Creating an Archive {: .info}\n> To create an archive:\n>   1) Ask archive_write_new for an archive writer object.\n>   2) Set any global properties.  In particular, you should set\n>      the compression and format to use.\n>   3) Call archive_write_open to open the file (most people\n>       will use archive_write_open_file or archive_write_open_fd,\n>       which provide convenient canned I/O callbacks for you).\n>   4) For each entry:\n>      - construct an appropriate struct archive_entry structure\n>      - archive_write_header to write the header\n>      - archive_write_data to write the entry data\n>   5) archive_write_close to close the output\n>   6) archive_write_free to cleanup the writer and release resources\n\n### `archive_write_disk`\n> #### Writing to Disk {: .info}\nTo create objects on disk:\n>   1) Ask archive_write_disk_new for a new archive_write_disk object.\n>   2) Set any global properties.  In particular, you probably\n>      want to set the options.\n>   3) For each entry:\n>      - construct an appropriate struct archive_entry structure\n>      - archive_write_header to create the file/dir/etc on disk\n>      - archive_write_data to write the entry data\n>   4) archive_write_free to cleanup the writer and release resources\n>s\n> In particular, you can use this in conjunction with archive_read()\n> to pull entries out of an archive and create them on disk.\n<!-- tabs-close -->\n\nIt also has `archive_read_extract` functions that combine reading with writing to disk.","ref":"Archive.Nif.html"},{"type":"function","title":"Archive.Nif.archive_bzlib_version/0","doc":"","ref":"Archive.Nif.html#archive_bzlib_version/0"},{"type":"function","title":"Archive.Nif.archive_clear_error/1","doc":"","ref":"Archive.Nif.html#archive_clear_error/1"},{"type":"function","title":"Archive.Nif.archive_compression/1","doc":"","ref":"Archive.Nif.html#archive_compression/1"},{"type":"function","title":"Archive.Nif.archive_compression_name/1","doc":"","ref":"Archive.Nif.html#archive_compression_name/1"},{"type":"function","title":"Archive.Nif.archive_entry_clear/1","doc":"","ref":"Archive.Nif.html#archive_entry_clear/1"},{"type":"function","title":"Archive.Nif.archive_entry_copy_stat/2","doc":"","ref":"Archive.Nif.html#archive_entry_copy_stat/2"},{"type":"function","title":"Archive.Nif.archive_entry_new/0","doc":"","ref":"Archive.Nif.html#archive_entry_new/0"},{"type":"function","title":"Archive.Nif.archive_entry_pathname/1","doc":"","ref":"Archive.Nif.html#archive_entry_pathname/1"},{"type":"function","title":"Archive.Nif.archive_entry_set_pathname/2","doc":"","ref":"Archive.Nif.html#archive_entry_set_pathname/2"},{"type":"function","title":"Archive.Nif.archive_entry_size/1","doc":"","ref":"Archive.Nif.html#archive_entry_size/1"},{"type":"function","title":"Archive.Nif.archive_entry_stat/1","doc":"","ref":"Archive.Nif.html#archive_entry_stat/1"},{"type":"function","title":"Archive.Nif.archive_error_string/1","doc":"","ref":"Archive.Nif.html#archive_error_string/1"},{"type":"function","title":"Archive.Nif.archive_file_count/1","doc":"","ref":"Archive.Nif.html#archive_file_count/1"},{"type":"function","title":"Archive.Nif.archive_format/1","doc":"","ref":"Archive.Nif.html#archive_format/1"},{"type":"function","title":"Archive.Nif.archive_format_name/1","doc":"","ref":"Archive.Nif.html#archive_format_name/1"},{"type":"function","title":"Archive.Nif.archive_liblz4_version/0","doc":"","ref":"Archive.Nif.html#archive_liblz4_version/0"},{"type":"function","title":"Archive.Nif.archive_liblzma_version/0","doc":"","ref":"Archive.Nif.html#archive_liblzma_version/0"},{"type":"function","title":"Archive.Nif.archive_libzstd_version/0","doc":"","ref":"Archive.Nif.html#archive_libzstd_version/0"},{"type":"function","title":"Archive.Nif.archive_read_close/1","doc":"","ref":"Archive.Nif.html#archive_read_close/1"},{"type":"function","title":"Archive.Nif.archive_read_data/2","doc":"","ref":"Archive.Nif.html#archive_read_data/2"},{"type":"function","title":"Archive.Nif.archive_read_extract/3","doc":"","ref":"Archive.Nif.html#archive_read_extract/3"},{"type":"function","title":"Archive.Nif.archive_read_format_capabilities/1","doc":"","ref":"Archive.Nif.html#archive_read_format_capabilities/1"},{"type":"function","title":"Archive.Nif.archive_read_new/0","doc":"","ref":"Archive.Nif.html#archive_read_new/0"},{"type":"function","title":"Archive.Nif.archive_read_next_header/2","doc":"","ref":"Archive.Nif.html#archive_read_next_header/2"},{"type":"function","title":"Archive.Nif.archive_read_open_filename/3","doc":"","ref":"Archive.Nif.html#archive_read_open_filename/3"},{"type":"function","title":"Archive.Nif.archive_read_open_memory/2","doc":"","ref":"Archive.Nif.html#archive_read_open_memory/2"},{"type":"function","title":"Archive.Nif.archive_read_refresh/1","doc":"","ref":"Archive.Nif.html#archive_read_refresh/1"},{"type":"function","title":"Archive.Nif.archive_read_support_compression_all/1","doc":"","ref":"Archive.Nif.html#archive_read_support_compression_all/1"},{"type":"function","title":"Archive.Nif.archive_read_support_filter_all/1","doc":"","ref":"Archive.Nif.html#archive_read_support_filter_all/1"},{"type":"function","title":"Archive.Nif.archive_read_support_filter_by_code/2","doc":"","ref":"Archive.Nif.html#archive_read_support_filter_by_code/2"},{"type":"function","title":"Archive.Nif.archive_read_support_format_all/1","doc":"","ref":"Archive.Nif.html#archive_read_support_format_all/1"},{"type":"function","title":"Archive.Nif.archive_read_support_format_by_code/2","doc":"","ref":"Archive.Nif.html#archive_read_support_format_by_code/2"},{"type":"function","title":"Archive.Nif.archive_read_support_format_raw/1","doc":"","ref":"Archive.Nif.html#archive_read_support_format_raw/1"},{"type":"function","title":"Archive.Nif.archive_version_details/0","doc":"","ref":"Archive.Nif.html#archive_version_details/0"},{"type":"function","title":"Archive.Nif.archive_version_string/0","doc":"","ref":"Archive.Nif.html#archive_version_string/0"},{"type":"function","title":"Archive.Nif.archive_write_add_filter/2","doc":"","ref":"Archive.Nif.html#archive_write_add_filter/2"},{"type":"function","title":"Archive.Nif.archive_write_close/1","doc":"","ref":"Archive.Nif.html#archive_write_close/1"},{"type":"function","title":"Archive.Nif.archive_write_header/2","doc":"","ref":"Archive.Nif.html#archive_write_header/2"},{"type":"function","title":"Archive.Nif.archive_write_new/0","doc":"","ref":"Archive.Nif.html#archive_write_new/0"},{"type":"function","title":"Archive.Nif.archive_write_open_filename/2","doc":"","ref":"Archive.Nif.html#archive_write_open_filename/2"},{"type":"function","title":"Archive.Nif.archive_write_refresh/1","doc":"","ref":"Archive.Nif.html#archive_write_refresh/1"},{"type":"function","title":"Archive.Nif.archive_write_set_format/2","doc":"","ref":"Archive.Nif.html#archive_write_set_format/2"},{"type":"function","title":"Archive.Nif.archive_zlib_version/0","doc":"","ref":"Archive.Nif.html#archive_zlib_version/0"},{"type":"function","title":"Archive.Nif.archiveFilterToAtom/1","doc":"","ref":"Archive.Nif.html#archiveFilterToAtom/1"},{"type":"function","title":"Archive.Nif.archiveFilterToInt/1","doc":"","ref":"Archive.Nif.html#archiveFilterToInt/1"},{"type":"function","title":"Archive.Nif.archiveFormatToAtom/1","doc":"","ref":"Archive.Nif.html#archiveFormatToAtom/1"},{"type":"function","title":"Archive.Nif.archiveFormatToInt/1","doc":"","ref":"Archive.Nif.html#archiveFormatToInt/1"},{"type":"macro","title":"Archive.Nif.call/1","doc":"","ref":"Archive.Nif.html#call/1"},{"type":"macro","title":"Archive.Nif.call/2","doc":"","ref":"Archive.Nif.html#call/2"},{"type":"function","title":"Archive.Nif.extractFlagToInt/1","doc":"","ref":"Archive.Nif.html#extractFlagToInt/1"},{"type":"function","title":"Archive.Nif.fileKinds/0","doc":"","ref":"Archive.Nif.html#fileKinds/0"},{"type":"function","title":"Archive.Nif.get_error_string/1","doc":"","ref":"Archive.Nif.html#get_error_string/1"},{"type":"macro","title":"Archive.Nif.get_file_kinds/0","doc":"","ref":"Archive.Nif.html#get_file_kinds/0"},{"type":"function","title":"Archive.Nif.getExtractInfo/0","doc":"","ref":"Archive.Nif.html#getExtractInfo/0"},{"type":"function","title":"Archive.Nif.isSubFormatOf/2","doc":"","ref":"Archive.Nif.html#isSubFormatOf/2"},{"type":"function","title":"Archive.Nif.list_all/2","doc":"","ref":"Archive.Nif.html#list_all/2"},{"type":"function","title":"Archive.Nif.listReadableFilters/0","doc":"","ref":"Archive.Nif.html#listReadableFilters/0"},{"type":"function","title":"Archive.Nif.listReadableFormats/0","doc":"","ref":"Archive.Nif.html#listReadableFormats/0"},{"type":"function","title":"Archive.Nif.listWritableFilters/0","doc":"","ref":"Archive.Nif.html#listWritableFilters/0"},{"type":"function","title":"Archive.Nif.listWritableFormats/0","doc":"","ref":"Archive.Nif.html#listWritableFormats/0"},{"type":"function","title":"Archive.Nif.safe_call/2","doc":"","ref":"Archive.Nif.html#safe_call/2"},{"type":"function","title":"Archive.Nif.unwrap/1","doc":"","ref":"Archive.Nif.html#unwrap/1"},{"type":"module","title":"Archive.Stat","doc":"","ref":"Archive.Stat.html"},{"type":"function","title":"Archive.Stat.combine_major_minor/2","doc":"","ref":"Archive.Stat.html#combine_major_minor/2"},{"type":"function","title":"Archive.Stat.file_kinds/0","doc":"","ref":"Archive.Stat.html#file_kinds/0"},{"type":"function","title":"Archive.Stat.file_stat_to_zig_map/1","doc":"","ref":"Archive.Stat.html#file_stat_to_zig_map/1"},{"type":"function","title":"Archive.Stat.major_minor/1","doc":"","ref":"Archive.Stat.html#major_minor/1"},{"type":"module","title":"Archive.Stream","doc":"","ref":"Archive.Stream.html"},{"type":"function","title":"Archive.Stream.init/1","doc":"Initializes the archive with the formats specified in `new/1`","ref":"Archive.Stream.html#init/1"},{"type":"function","title":"Archive.Stream.init!/1","doc":"","ref":"Archive.Stream.html#init!/1"},{"type":"function","title":"Archive.Stream.new/1","doc":"","ref":"Archive.Stream.html#new/1"},{"type":"module","title":"Archive.Utils","doc":"","ref":"Archive.Utils.html"},{"type":"function","title":"Archive.Utils.hierarchical/1","doc":"Converts a list of `Archive.Entry` to a hierachical map, similar to a filesystem structure.","ref":"Archive.Utils.html#hierarchical/1"},{"type":"exception","title":"Archive.Error","doc":"","ref":"Archive.Error.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}